@@ -43,6 +43,8 @@ code from qwriter:
 #include "utils.h"
 #include "gui_utils.h"
 
+#include "textproc.h"
+
 #include <QSettings>
 #include <QLabel>
 #include <QPainter>
@@ -52,6 +54,8 @@ code from qwriter:
 #include <QXmlStreamReader>
 #include <QMimeData>
 
+#include <bitset>
+
 #if QT_VERSION >= 0x050000
 
 #include <QRegularExpression>
@@ -63,6 +67,7 @@ QHash <QString, QString> global_palette;
 QSettings *settings;
 QMenu *current_files_menu;
 
+bool b_recent_off;
 
 void CDocument::update_status()
 {
@@ -489,8 +494,6 @@ QString CDocument::get_filename_at_cursor()
         return QString();
 
      x = x.mid (i + 1);   
-
-//     qDebug() << "x = " << x;
      
      result = cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
      //qDebug() << "in cur dir: " << result;
@@ -525,8 +528,9 @@ QString CDocument::get_filename_at_cursor()
 
 CSyntaxHighlighter::CSyntaxHighlighter (QTextDocument *parent, CDocument *doc, const QString &fname): QSyntaxHighlighter (parent) 
 {
-  qDebug() << "CSyntaxHighlighter::CSyntaxHighlighter";
+  //qDebug() << "CSyntaxHighlighter::CSyntaxHighlighter";
   document = doc; 
+  xml_format = 0;
   //casecare = true; 
   //wrap = true;
 }
@@ -547,14 +551,12 @@ CSyntaxHighlighterQRegExp::CSyntaxHighlighterQRegExp (QTextDocument *parent, CDo
 CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression (QTextDocument *parent, CDocument *doc, const QString &fname):
                                                                             CSyntaxHighlighter (parent, doc, fname)
 {
-  qDebug() << "CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression";
+  //qDebug() << "CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression";
 
   document = doc;
   //casecare = true;
   //wrap = true;
   load_from_xml (fname);
-  
-  qDebug() << "555 wrap: " << wrap;
 }
 
 #endif
@@ -637,7 +639,8 @@ void document_holder::apply_settings_single (CDocument *d)
   d->textEdit->lineNumberArea->setFont (f);
 */
 
-  
+  d->textEdit->setCursorWidth (settings->value ("cursor_width", 2).toInt());
+ 
   d->textEdit->setCenterOnScroll (settings->value ("center_on_scroll", true).toBool());
   
   d->textEdit->use_hl_wrap = settings->value ("use_hl_wrap", true).toBool();
@@ -722,6 +725,9 @@ void document_holder::apply_settings()
 
 void document_holder::add_to_recent (CDocument *d)
 {
+  if (b_recent_off)
+     return;
+
   if (! file_exists (d->file_name))
      return;
 
@@ -939,6 +945,7 @@ CTEAEdit::CTEAEdit (QWidget *parent): QPlainTextEdit (parent)
   spaces_instead_of_tabs = true;
   
   //document()->setDefaultTextOption(QTextOption(Qt::AlignRight));
+ // setCursorWidth (settings->value ("cursor_width", 1).toInt());
   
   connect (this, SIGNAL(cursorPositionChanged()), this, SLOT(cb_cursorPositionChanged()));
 }
@@ -1053,6 +1060,10 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 
                  if (attr_name == "options")
                     {
+                     QString s_xml_format = xml.attributes().value ("xml_format").toString();
+                     if (! s_xml_format.isNull() || ! s_xml_format.isEmpty())
+                        xml_format = s_xml_format.toInt();
+                    
                      QString s_wrap = xml.attributes().value ("wrap").toString();
                      if (! s_wrap.isNull() || ! s_wrap.isEmpty())
                         if (s_wrap == "0" || s_wrap == "false")
@@ -1069,26 +1080,39 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 
                  if (attr_type == "keywords")
                     {
-//                     QString color = hash_get_val (document->holder->global_palette, xml.attributes().value ("color").toString(), "darkBlue");
                      QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "darkBlue");
 
                      QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
-                     QStringList keywordPatterns = xml.readElementText().trimmed().split(";");
+                     if (xml_format == 0)
+                        {
+                         QStringList keywordPatterns = xml.readElementText().trimmed().split(";");
 
-                     HighlightingRule rule;
+                         HighlightingRule rule;
 
-                     for (int i = 0; i < keywordPatterns.size(); i++)
-                          if (! keywordPatterns.at(i).isNull())
-                             {
-                              rule.pattern = QRegularExpression (keywordPatterns.at(i).trimmed(), pattern_opts);
-                              rule.format = fmt;
-                              highlightingRules.append (rule);
-                              
-                              if (! rule.pattern.isValid())
-                                  qDebug() << "! valid " << rule.pattern.pattern();
+                         for (int i = 0; i < keywordPatterns.size(); i++)
+                              if (! keywordPatterns.at(i).isNull())
+                                 {
+                                  rule.pattern = QRegularExpression (keywordPatterns.at(i).trimmed(), pattern_opts);
+                                  rule.format = fmt;
+                                  highlightingRules.append (rule);
                               
+                                  if (! rule.pattern.isValid())
+                                     qDebug() << "! valid " << rule.pattern.pattern();
                              }
+                         }       
+                      else
+                      if (xml_format == 1)
+                         {
+                          HighlightingRule rule;
+                          rule.pattern = QRegularExpression (xml.readElementText().trimmed().remove('\n'), pattern_opts);
+                          rule.format = fmt;
+                          highlightingRules.append(rule);
+                        
+                          if (! rule.pattern.isValid())
+                             qDebug() << "! valid " << rule.pattern.pattern();
+                         }
+                             
                      } //keywords
                  else
                     if (attr_type == "item")
@@ -1127,7 +1151,6 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                             else
                             if (xml.attributes().value ("name").toString() == "cm_single")
                                cm_single = xml.readElementText().trimmed();
-
                           }
 
                      }//item
@@ -1152,11 +1175,8 @@ void CSyntaxHighlighterQRegularExpression::highlightBlock (const QString &text)
            while (index >= 0)
                  {
                   int length = m.capturedLength();
-                   
                   setFormat (index, length, rule.format);
-  
                   m = rule.pattern.match (text, index + length);
-
                   index = m.capturedStart();
                  }
           }
@@ -1214,7 +1234,7 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
   QString temp = qstring_load (fname);
   QXmlStreamReader xml (temp);
 
-   while (! xml.atEnd())
+  while (! xml.atEnd())
         {
          xml.readNext();
 
@@ -1257,55 +1277,68 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
                      QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "darkBlue");
                      QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
-                     QStringList keywordPatterns = xml.readElementText().trimmed().split(";");
+                     if (xml_format == 0)
+                        {
+                         QStringList keywordPatterns = xml.readElementText().trimmed().split(";");
 
-                     HighlightingRule rule;
+                         HighlightingRule rule;
 
-                     for (int i = 0; i < keywordPatterns.size(); i++)
-                          if (! keywordPatterns.at(i).isNull())
-                             {
-                              rule.pattern = QRegExp (keywordPatterns.at(i).trimmed(), cs, QRegExp::RegExp);
-                              rule.format = fmt;
-                              highlightingRules.append (rule);
-                             }
+                         for (int i = 0; i < keywordPatterns.size(); i++)
+                             if (! keywordPatterns.at(i).isNull())
+                                {
+                                 rule.pattern = QRegExp (keywordPatterns.at(i).trimmed(), cs, QRegExp::RegExp);
+                                 rule.format = fmt;
+                                 highlightingRules.append (rule);
+                                }
+                          }
+                     else
+                         if (xml_format == 1)
+                            {
+                             HighlightingRule rule;
+                             rule.pattern = QRegExp (xml.readElementText().trimmed().remove('\n'), cs);
+                             rule.format = fmt;
+                             highlightingRules.append(rule);
+                        
+                             if (! rule.pattern.isValid())
+                                qDebug() << "! valid " << rule.pattern.pattern();
+                            }
+                            
                      } //keywords
                  else
-                    if (attr_type == "item")
-                       {
-                        QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "darkBlue");
-                        QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
+                 if (attr_type == "item")
+                    {
+                     QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "darkBlue");
+                     QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
-                        HighlightingRule rule;
-                        rule.pattern = QRegExp (xml.readElementText().trimmed(), cs, QRegExp::RegExp);
-                        rule.format = fmt;
-                        highlightingRules.append(rule);
-                       }
-                    else
-                        if (attr_type == "mcomment-start")
-                           {
-                            QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "gray");
-                            QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("color").toString(), color, darker_val);
+                     HighlightingRule rule;
+                     rule.pattern = QRegExp (xml.readElementText().trimmed(), cs, QRegExp::RegExp);
+                     rule.format = fmt;
+                     highlightingRules.append(rule);
+                    }
+                 else
+                 if (attr_type == "mcomment-start")
+                    {
+                     QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "gray");
+                     QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("color").toString(), color, darker_val);
 
-                            multiLineCommentFormat = fmt;
-                            commentStartExpression = QRegExp (xml.readElementText().trimmed(), cs, QRegExp::RegExp);
-                           }
-                    else
-                        if (attr_type == "mcomment-end")
-                           {
-                            commentEndExpression = QRegExp (xml.readElementText().trimmed(), cs, QRegExp::RegExp);
-                           }
-                    else
-                        if (attr_type == "comment")
-                           {
-                            if (xml.attributes().value ("name").toString() == "cm_mult")
-                               cm_mult = xml.readElementText().trimmed();
-                            else
-                            if (xml.attributes().value ("name").toString() == "cm_single")
-                               cm_single = xml.readElementText().trimmed();
-
-                          }
-
-                     }//item
+                     multiLineCommentFormat = fmt;
+                     commentStartExpression = QRegExp (xml.readElementText().trimmed(), cs, QRegExp::RegExp);
+                    }
+                 else
+                 if (attr_type == "mcomment-end")
+                    {
+                     commentEndExpression = QRegExp (xml.readElementText().trimmed(), cs, QRegExp::RegExp);
+                    }
+                 else
+                 if (attr_type == "comment")
+                    {
+                     if (xml.attributes().value ("name").toString() == "cm_mult")
+                         cm_mult = xml.readElementText().trimmed();
+                     else
+                         if (xml.attributes().value ("name").toString() == "cm_single")
+                            cm_single = xml.readElementText().trimmed();
+                    }
+                }//item
 
        }//is start
 
@@ -1313,7 +1346,6 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
      qDebug() << "xml parse error";
 
   } //cycle
-  
 }
 
 
@@ -1330,7 +1362,6 @@ void CSyntaxHighlighterQRegExp::highlightBlock (const QString &text)
                  {
                   int length = rule.pattern.matchedLength();
                   setFormat (index, length, rule.format);
-
                   index = text.indexOf (rule.pattern, index + length);
                  }
            }
@@ -1359,7 +1390,6 @@ void CSyntaxHighlighterQRegExp::highlightBlock (const QString &text)
              commentLength = endIndex - startIndex + commentEndExpression.matchedLength();
 
          setFormat (startIndex, commentLength, multiLineCommentFormat);
-
          startIndex = text.indexOf (commentStartExpression, startIndex + commentLength);
         }
 }
@@ -1709,9 +1739,87 @@ void CTEAEdit::un_indent()
   setTextCursor (cur);
 }
 
+#define SK_A 38
+#define SK_D 40
+#define SK_W 25
+#define SK_S 39
+
+#define SK_E 26
+#define SK_C 54
+
 
 void CTEAEdit::keyPressEvent (QKeyEvent *event)
 {
+ // qDebug() << event->nativeScanCode() ; 
+
+ // qDebug() << int_to_binary (event->nativeModifiers());
+  // std::bitset<32> btst (event->nativeModifiers());
+   
+   /*
+   for (std::size_t i = 0; i < btst.size(); ++i) {
+        qDebug() << "btst[" << i << "]: " << btst[i];
+    }
+   */
+   //LSHIFT = 0
+//LCTRL = 2
+//LALT = 3
+  //LWIN = 6
+  if (settings->value ("wasd", "0").toInt())
+     {
+      std::bitset<32> btst (event->nativeModifiers());
+      QTextCursor cr = textCursor();
+
+      QTextCursor::MoveMode m = QTextCursor::MoveAnchor;
+
+// if (btst[0] == 1)
+         //    m = QTextCursor::KeepAnchor;
+       
+      if (btst[3] == 1 || btst[6] == 1) //LALT or LWIN
+         {
+          int visible_lines;
+
+          if (btst[6] == 1)
+             m = QTextCursor::KeepAnchor;
+
+          switch (event->nativeScanCode())
+                 {
+                  case SK_W:
+                                 cr.movePosition (QTextCursor::Up, m);
+                                 setTextCursor (cr);
+                                 return;
+
+                  case SK_S:
+                                 cr.movePosition (QTextCursor::Down, m);
+                                 setTextCursor (cr);
+                                 return;
+
+                  case SK_A:
+                                 cr.movePosition (QTextCursor::Left, m);
+                                 setTextCursor (cr);
+                                 return;
+
+                  case SK_D:
+                                 cr.movePosition (QTextCursor::Right, m);
+                                 setTextCursor (cr);
+                                 return;
+                                 
+                   case SK_E:
+                                  visible_lines = height() / fontMetrics().height();
+                                  cr.movePosition (QTextCursor::Down, m, visible_lines);
+                                  setTextCursor (cr);
+                                  return;               
+                                  
+                   case SK_C:
+                                  visible_lines = height() / fontMetrics().height();
+                                  cr.movePosition (QTextCursor::Up, m, visible_lines);
+                                  setTextCursor (cr);
+                                  return;               
+                                     
+                 }
+      
+       }
+    } 
+
   if (auto_indent)
      if (event->key() == Qt::Key_Return)
         {
@@ -1734,6 +1842,13 @@ void CTEAEdit::keyPressEvent (QKeyEvent *event)
       event->accept();
       return;
      }
+  else
+  if (event->key() == Qt::Key_Insert)
+     {
+      setOverwriteMode (! overwriteMode());
+      event->accept();
+      return;
+     }   
   
   QPlainTextEdit::keyPressEvent (event);
 }
@@ -2155,3 +2270,4 @@ void CSyntaxHighlighter::highlightBlock (const QString &text)
  
  * 
  */
+
