@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2015 by Peter Semiletov <tea@list.ru>                            *
+ *   2007-2016 by Peter Semiletov <tea@list.ru>                            *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -47,6 +47,7 @@ code from qwriter:
 #include <QTabWidget>
 #include <QPlainTextEdit>
 #include <QSyntaxHighlighter>
+//#include <QDebug>
 
 #if QT_VERSION >= 0x050000
 
@@ -126,7 +127,17 @@ protected:
   void paintEvent(QPaintEvent *event);
   void keyPressEvent (QKeyEvent *event);    
   void resizeEvent(QResizeEvent *event);
+  
+  /*
+ bool event(QEvent *ev) {
+        if (ev->type() == QEvent::KeyboardLayoutChange) {
+            qDebug() << "kb layout changed";
+        } else {
+            return QWidget::event(ev);
+        }
 
+    }
+*/
 private slots:
 
   void updateLineNumberAreaWidth (int newBlockCount);
@@ -139,14 +150,14 @@ class CSyntaxHighlighter: public QSyntaxHighlighter
 {
 public:
  
-  //CSyntaxHighlighter (QTextDocument *parent): QSyntaxHighlighter (parent) {document = 0; casecare = true; wrap = true;};
   CSyntaxHighlighter (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
-  
  
   CDocument *document;
   bool casecare;
   bool wrap;
   
+  int xml_format;
+  
   QString exts;
   QString langs;
     
@@ -183,7 +194,7 @@ public:
 
   QVector <HighlightingRule> highlightingRules;
  
-   void load_from_xml (const QString &fname);
+  void load_from_xml (const QString &fname);
 };
 
 
@@ -209,17 +220,6 @@ public:
   QRegularExpression commentEndExpression;
 
   QRegularExpression::PatternOptions pattern_opts;
-
-  
-  CDocument *document;
-  bool casecare;
-  bool wrap;
-  
-  QString exts;
-  QString langs;
-    
-  QString cm_mult;
-  QString cm_single;
     
   CSyntaxHighlighterQRegularExpression (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
 
