@@ -87,6 +87,8 @@ public:
 };
 */
 
+
+
 class CMarkupPair: public QObject
 {
   Q_OBJECT
@@ -182,6 +184,8 @@ public:
   QQmlEngine *qml_engine;
 
 #endif
+
+  QAction *last_action;
   
   int fm_entry_mode; 
 
@@ -359,6 +363,10 @@ public:
 
   QSpinBox *spb_img_quality;
   QCheckBox *cb_zip_after_scale;
+  
+  QCheckBox *cb_exif_rotate;
+  
+  QCheckBox *cb_zor_use_exif;
 
 
 protected:
@@ -371,10 +379,14 @@ protected:
 
 public slots:
 
+
+
 /*************************
 main window callbacks
 *************************/
 
+  void repeat();
+
   void receiveMessage(const QString &msg);
   
   void view_use_theme();
@@ -524,6 +536,9 @@ main window callbacks
   void fn_sort_casecare();
   void fn_sort_casecareless();
 
+  void fn_sort_casecare_sep();
+  
+
   void fn_sort_latex_table_by_col_abc();
   void fn_table_swap_cells();
   void fn_table_delete_cells();
@@ -531,6 +546,9 @@ main window callbacks
       
   
   void fn_flip_a_list();
+  void fn_flip_a_list_sep();
+
+  
   void fn_insert_loremipsum();
   void fn_insert_template_html();
   void fn_run_script();
@@ -546,6 +564,10 @@ main window callbacks
   void fn_filter_delete_after_sep();
 
   void fn_rm_formatting();
+  
+   void fn_rm_compress();
+ 
+  
   void fn_convert_quotes_angle();
   void fn_convert_quotes_curly();
   
@@ -604,6 +626,13 @@ main window callbacks
 
 #endif
 
+  void scale_image();
+
+
+  void search_mark_all();
+  void search_unmark();
+
+
   void search_in_files_results_dclicked (QListWidgetItem *item);
   void search_in_files();
 
@@ -713,6 +742,8 @@ main window callbacks
   void cal_add_months();
   void cal_add_years();
 
+  void recentoff();
+  
 
 /*************************
 prefs window callbacks
@@ -850,6 +881,8 @@ main window widgets
   QAction *menu_find_regexp;
   QAction *menu_find_fuzzy;
 
+  QAction *menu_recent_off;
+
   QWidget *w_right;
   QLineEdit *ed_fman_fname;
   QComboBox *cb_fman_codecs;
@@ -878,6 +911,9 @@ prefs window widgets
   QLineEdit *ed_locale_override;
   QLineEdit *ed_img_viewer_override;
   
+  QSpinBox *spb_cursor_blink_time;
+  QSpinBox *spb_cursor_width;
+  
   CShortcutEntry *ent_shtcut;
   QListWidget *lv_menuitems;
 
@@ -892,6 +928,7 @@ prefs window widgets
   QSplitter *spl_fman;
 
   QCheckBox *cb_altmenu;
+  QCheckBox *cb_wasd;
   
 
   QCheckBox *cb_auto_img_preview;
@@ -917,6 +954,10 @@ prefs window widgets
 
   void update_stylesheet (const QString &f);
   
+  QString theme_dir;
+  
+  QIcon get_theme_icon (const QString &name);
+  QString get_theme_icon_fname (const QString &name);
 
   void update_dyn_menus();
   void create_paths();
@@ -1005,6 +1046,9 @@ prefs window widgets
  
   Q_INVOKABLE QString fif_get_text();
   
+  
+  
+  
   void fn_filter_delete_by_sep (bool mode);
 
   void fman_items_select_by_regexp (bool mode);
@@ -1054,6 +1098,7 @@ public:
   void saveState (QSessionManager &manager);
 };
 
+
 #if QT_VERSION >= 0x050000
 
 class CQQuickWindow: public QQuickWindow
