@@ -844,7 +844,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation>Aide</translation>
+        <translation type="obsolete">Aide</translation>
     </message>
     <message>
         <source>NEWS</source>
@@ -1505,10 +1505,6 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>Moon phase algorithm</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>UI tabs align</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Up</source>
         <translation type="unfinished"></translation>
@@ -1613,10 +1609,6 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>Old syntax hl engine (restart TEA to apply)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Instr</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Font gallery</source>
         <translation type="unfinished"></translation>
@@ -1758,10 +1750,6 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>FIF</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov, tea@list.ru&lt;br&gt;site 1: http://semiletov.org/tea&lt;br&gt;site 2: http://tea.ourproject.org&lt;br&gt;site 3 (development): https://github.com/psemiletov/tea-qt&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Sum by last column</source>
         <translation type="unfinished"></translation>
@@ -1770,5 +1758,81 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>sum: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Tools</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sort case sensitively, with separator</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flip a list with separator</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Compress</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cursor width</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply hard rotation by EXIF data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>EXIF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use EXIF orientation at image viewer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cursor blink time (msecs, zero is OFF)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov, tea@list.ru&lt;br&gt;sites: semiletov.org/tea and tea.ourproject.org&lt;br&gt;development: github.com/psemiletov/tea-qt&lt;br&gt;VK: vk.com/teaeditor&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unmark</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>GUI tabs align</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mark all found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not add to recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Left Alt + WASD as additional cursor keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Repeat last</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Incorrect parameters at FIF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Saved: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
